local font = love.graphics.newFont(24)
love.graphics.setFont(font)

local center_x, center_y = love.graphics.getWidth() / 2, love.graphics.getHeight() / 2
local hour_angle_offset = math.pi * 2 / 12
local min_sec_angle_offset = math.pi * 2 / 60

function love.draw()
    love.graphics.setColor(255, 255, 255)

    for i = 1, 12 do
        love.graphics.print(i, center_x - math.cos(math.pi / 2 + hour_angle_offset * i) * 130 - font:getWidth(i) / 2, center_y - math.sin(math.pi / 2 + hour_angle_offset * i) * 130 - font:getHeight() / 2)
    end

    for i = 1, 60 do
        local radius = i % 5 == 0 and 4 or 2

        if radius == 4 then
            love.graphics.setColor(0, 255, 0)
        else
            love.graphics.setColor(255, 255, 255)
        end

        love.graphics.circle("fill", center_x - math.cos(math.pi / 2 + min_sec_angle_offset * i) * 150, center_y - math.sin(math.pi / 2 + min_sec_angle_offset * i) * 150, radius)
    end

    love.graphics.setColor(255, 255, 255)

    local date = os.date("*t")
    date.hour = date.hour % 12

    local hour_angle = math.pi / 2 + hour_angle_offset * date.hour + (min_sec_angle_offset * date.min) / 12
    local hour_hand_length = 100
    love.graphics.line(center_x, center_y, center_x - math.cos(hour_angle) * hour_hand_length, center_y - math.sin(hour_angle) * hour_hand_length)

    local minute_angle = math.pi / 2 + min_sec_angle_offset * date.min
    local minute_hand_length = 130
    love.graphics.line(center_x, center_y, center_x - math.cos(minute_angle) * minute_hand_length, center_y - math.sin(minute_angle) * minute_hand_length)

    love.graphics.setColor(255, 0, 0)

    local second_angle = math.pi / 2 + min_sec_angle_offset * date.sec
    local second_hand_length = 120
    love.graphics.line(center_x, center_y, center_x - math.cos(second_angle) * second_hand_length, center_y - math.sin(second_angle) * second_hand_length)

    love.graphics.setColor(255, 255, 255)

    love.graphics.rectangle("line", center_x + 60, center_y - font:getHeight() / 2, font:getWidth(date.day), font:getHeight())
    love.graphics.print(date.day, center_x + 60, center_y - font:getHeight() / 2)
end